;Project Lynxmotion T-Hex
;Description: T-Hex 4 DOF, configuration file.
;		All Hardware connections (excl controls) and body dimensions 
;		are configurated in this file. Can be used with V2.0 and above
;Date: 20-11-2010
;Programmer: Jeroen Janssen (aka Xan) and modified by Kre Halvorsen (aka Zenta)
;
;Hardware setup: ABB2 with ATOM 28 Pro, SSC32 V2, (See further for connections)
;
;
UseCodeOffsets 		con 1 	;Comment this line if you are using the internal SSC32 registry offsets
BinaryMode 			con 1 	;Comment this line if you don't want to use the SSC32 binary mode
LiPoSafetyON		con 1	;Comment this line if you are not using a 2S LiPo directly to the VL
;PERLEGCONFIG 		con 1	; Comment this line if all of the legs are the same...
; Note: cTarsLength if defined below turns on 4dof mode...

;USEPS2			con 1
USEXBEE			con 1
;--------------------------------------------------------------------
;[SERIAL CONNECTIONS]
cSSC_OUT   		con P11		;Output pin for (SSC32 RX) on BotBoard (Yellow)
cSSC_IN    		con P10		;Input pin for (SSC32 TX) on BotBoard (Blue)
cSSC_BAUD 		con i115200	;SSC32 BAUD rate 115200 require the Studio version 2.0.0.7 or later
;--------------------------------------------------------------------
;[BB2 PIN NUMBERS]
cEyesPin		con P8

#ifdef BASICATOMPRO28
CXBEE_RTS		con	p7	' put on a pin that has lower voltages (Only used if USEXBEE is defined)
cSound			con P9	; Standard sound pin on Atom Bot Board 2
#else
cSound			con P19	; lets try output sound on plug in speaker
CXBEE_RTS		con P34 ' put on a pin that has lower voltage (SCL/SDA)
#endif

;--------------------------------------------------------------------
;[SSC PIN NUMBERS]
cPanHeadPin		con P31
cTiltHeadPin	con P32

cRRCoxaPin 		con P24	;Rear Right leg Hip Horizontal
cRRFemurPin 	con P25	;Rear Right leg Hip Vertical
cRRTibiaPin 	con P26	;Rear Right leg Knee
cRRTarsPin 		con P27

cRMCoxaPin 		con P20	;Middle Right leg Hip Horizontal
cRMFemurPin 	con P21	;Middle Right leg Hip Vertical
cRMTibiaPin 	con P22	;Middle Right leg Knee
cRMTarsPin 		con P23

cRFCoxaPin 		con P16	;Front Right leg Hip Horizontal
cRFFemurPin 	con P17	;Front Right leg Hip Vertical
cRFTibiaPin 	con P18	;Front Right leg Knee
cRFTarsPin 		con P19

cLRCoxaPin 		con P8	;Rear Left leg Hip Horizontal
cLRFemurPin 	con P9	;Rear Left leg Hip Vertical
cLRTibiaPin 	con P10	;Rear Left leg Knee
cLRTarsPin 		con P11

cLMCoxaPin 		con P4	;Middle Left leg Hip Horizontal
cLMFemurPin 	con P5	;Middle Left leg Hip Vertical
cLMTibiaPin 	con P6	;Middle Left leg Knee
cLMTarsPin 		con P7

cLFCoxaPin 		con P0	;Front Left leg Hip Horizontal
cLFFemurPin 	con P1	;Front Left leg Hip Vertical
cLFTibiaPin 	con P2	;Front Left leg Knee
cLFTarsPin 		con P3
;--------------------------------------------------------------------
#IFDEF UseCodeOffsets
;[SERVO Offsets]
cRFCoxaOffset 	con 650+2	;Front Right leg Hip Horizontal		
cRFFemurOffset 	con 650-67	;Front Right leg Hip Vertical	
cRFTibiaOffset  con 650+317	;Front Right leg Knee			
cRFTarsOffset 	con 650-396	;Front Right leg foot			

cRMCoxaOffset 	con 650-12	;Middle Right leg Hip Horizontal
cRMFemurOffset 	con 650-104	;Middle Right leg Hip Vertical		
cRMTibiaOffset  con 650+363	;Middle Right leg Knee			
cRMTarsOffset 	con 650-378	;Middle Right leg foot			

cRRCoxaOffset 	con 650-68	;Rear Right leg Hip Horizontal		
cRRFemurOffset 	con 650-32	;Rear Right leg Hip Vertical	
cRRTibiaOffset  con 650+438	;Rear Right leg Knee			
cRRTarsOffset 	con 650-289	;Rear Right leg foot			

cLFCoxaOffset 	con 650+89	;Front Left leg Hip Horizontal		
cLFFemurOffset 	con 650+183	;Front Left leg Hip Vertical		
cLFTibiaOffset  con 650-245	;Front Left leg Knee			
cLFTarsOffset 	con 650+416;Front Left leg foot			

cLMCoxaOffset 	con 650+58	;Middle Left leg Hip Horizontal	
cLMFemurOffset 	con 650+59	;Middle Left leg Hip Vertical		
cLMTibiaOffset  con 650-313	;Middle Left leg Knee				
cLMTarsOffset 	con 650+338	;Middle Left leg foot				

cLRCoxaOffset 	con 650-66	;Rear Left leg Hip Horizontal		
cLRFemurOffset 	con 650+115	;Rear Left leg Hip Vertical			
cLRTibiaOffset  con 650-405	;Rear Left leg Knee					
cLRTarsOffset 	con 650+356	;Rear Left leg foot	
#ELSE
;--------------------------------------------------------------------
;[Joint offsets]
;First calibrate the servos in the 0 deg position using the SSC-32 reg offsets, then:
cFemurHornOffset	con 150 ;Snap out the horn one click upward
cTarsHornOffset		con 150 ;Snap out the horn one click inward
;--------------------------------------------------------------------
#ENDIF				

;--------------------------------------------------------------------
;[MIN/MAX ANGLES]
cRRCoxaMin1		con -650	;Mechanical limits of the Right Rear Leg, decimals = 1
cRRCoxaMax1		con 650
cRRFemurMin1	con -1050
cRRFemurMax1	con 750
cRRTibiaMin1	con -530
cRRTibiaMax1	con 900
cRRTarsMin1		con -1300	;In theory the kinematics can reach about -160 deg
cRRTarsMax1		con 500		;The kinematics will never exceed 23 deg though..

cRMCoxaMin1		con -530	;Mechanical limits of the Right Middle Leg, decimals = 1
cRMCoxaMax1		con 530
cRMFemurMin1	con -1050
cRMFemurMax1	con 750
cRMTibiaMin1	con -530
cRMTibiaMax1	con 900
cRMTarsMin1		con -1300
cRMTarsMax1		con 500

cRFCoxaMin1		con -550	;Mechanical limits of the Right Front Leg, decimals = 1
cRFCoxaMax1		con 650
cRFFemurMin1	con -1050
cRFFemurMax1	con 750
cRFTibiaMin1	con -530
cRFTibiaMax1	con 900
cRFTarsMin1		con -1300
cRFTarsMax1		con 500

cLRCoxaMin1		con -650	;Mechanical limits of the Left Rear Leg, decimals = 1
cLRCoxaMax1		con 650
cLRFemurMin1	con -1050
cLRFemurMax1	con 750
cLRTibiaMin1	con -530
cLRTibiaMax1	con 900
cLRTarsMin1		con -1300
cLRTarsMax1		con 500

cLMCoxaMin1		con -530	;Mechanical limits of the Left Middle Leg, decimals = 1
cLMCoxaMax1		con 530
cLMFemurMin1	con -1050
cLMFemurMax1	con 750
cLMTibiaMin1	con -530
cLMTibiaMax1	con 900
cLMTarsMin1		con -1300
cLMTarsMax1		con 500

cLFCoxaMin1		con -550	;Mechanical limits of the Left Front Leg, decimals = 1
cLFCoxaMax1		con 650
cLFFemurMin1	con -1050
cLFFemurMax1	con 750
cLFTibiaMin1	con -530
cLFTibiaMax1	con 900
cLFTarsMin1		con -1300
cLFTarsMax1		con 500
;--------------------------------------------------------------------
;[BODY DIMENSIONS]
cCoxaLength  	con 29		;Length of the Coxa [mm]
cFemurLength 	con 75		;Length of the Femur [mm]
cTibiaLength 	con 71		;Lenght of the Tibia [mm]

; Note: defining cTarslength here turns on 4dof mode...
cTarsLength		con	85		;Lenght of the Tars [mm]

cRRCoxaAngle1 	con -450	;Default Coxa setup angle, decimals = 1
cRMCoxaAngle1 	con 0		;Default Coxa setup angle, decimals = 1
cRFCoxaAngle1 	con 450		;Default Coxa setup angle, decimals = 1
cLRCoxaAngle1 	con -450	;Default Coxa setup angle, decimals = 1
cLMCoxaAngle1 	con 0		;Default Coxa setup angle, decimals = 1
cLFCoxaAngle1 	con 450		;Default Coxa setup angle, decimals = 1

cRROffsetX 		con -56		;Distance X from center of the body to the Right Rear coxa
cRROffsetZ 		con 102		;Distance Z from center of the body to the Right Rear coxa
cRMOffsetX 		con -75		;Distance X from center of the body to the Right Middle coxa
cRMOffsetZ 		con 0		;Distance Z from center of the body to the Right Middle coxa
cRFOffsetX 		con -63		;Distance X from center of the body to the Right Front coxa
cRFOffsetZ 		con -102	;Distance Z from center of the body to the Right Front coxa

cLROffsetX 		con 56		;Distance X from center of the body to the Left Rear coxa
cLROffsetZ 		con 102		;Distance Z from center of the body to the Left Rear coxa
cLMOffsetX 		con 75		;Distance X from center of the body to the Left Middle coxa
cLMOffsetZ 		con 0		;Distance Z from center of the body to the Left Middle coxa
cLFOffsetX 		con 63		;Distance X from center of the body to the Left Front coxa
cLFOffsetZ 		con -102	;Distance Z from center of the body to the Left Front coxa

#ifdef PERLEGCONFIG
cRRCoxaLength	con cCoxaLength		; right now all are the same length
cRMCoxaLength	con cCoxaLength
cRFCoxaLength	con cCoxaLength
cLRCoxaLength	con cCoxaLength
cLMCoxaLength	con cCoxaLength
cLFCoxaLength	con cCoxaLength
cRRFemurLength 	con cFemurLength
cRMFemurLength 	con cFemurLength
cRFFemurLength 	con cFemurLength
cLRFemurLength 	con cFemurLength
cLMFemurLength 	con cFemurLength
cLFFemurLength 	con cFemurLength
cRRTibiaLength 	con cTibiaLength
cRMTibiaLength 	con cTibiaLength
cRFTibiaLength 	con cTibiaLength
cLRTibiaLength 	con cTibiaLength
cLMTibiaLength 	con cTibiaLength
cLFTibiaLength 	con cTibiaLength
#ifdef cTarsLength  ; Warning: uses cTarsLength to turn on or off 4dof mode needed even in Per leg mode...
cRRTarsLength	con	cTarsLength
cRMTarsLength	con	cTarsLength
cRFTarsLength	con	cTarsLength
cLRTarsLength	con	cTarsLength
cLMTarsLength	con	cTarsLength
cLFTarsLength	con	cTarsLength
#endif
#endif



;--------------------------------------------------------------------
;[START POSITIONS FEET]
CHexInitY		con 18		; All of them are the same used in experment 
cRRInitPosX 	con 72		;Start positions of the Right Rear leg
cRRInitPosY 	con CHexInitY
cRRInitPosZ 	con 72

cRMInitPosX 	con 102		;Start positions of the Right Middle leg
cRMInitPosY 	con CHexInitY
cRMInitPosZ 	con 0

cRFInitPosX 	con 72		;Start positions of the Right Front leg
cRFInitPosY 	con CHexInitY
cRFInitPosZ 	con -72

cLRInitPosX 	con 72		;Start positions of the Left Rear leg
cLRInitPosY 	con CHexInitY
cLRInitPosZ 	con 72

cLMInitPosX 	con 102		;Start positions of the Left Middle leg
cLMInitPosY 	con CHexInitY
cLMInitPosZ 	con 0

cLFInitPosX 	con 72		;Start positions of the Left Front leg
cLFInitPosY 	con CHexInitY
cLFInitPosZ 	con -72

;--------------------------------------------------------------------
;[Tars factors used in formula to calc Tarsus angle relative to the ground]
cTarsConst		con	720
cTarsMulti		con 2
cTarsFactorA	con 70
cTarsFactorB	con 60
cTarsFactorC	con 50